@@ -1,10 +1,11 @@
 #!/usr/bin/env python3
 from __future__ import print_function
 
-VERSION = '0.4.10'
+VERSION = '0.4.12'
 
 import os
 import sys
+import glob
 import shutil
 import fileinput
 import functools
@@ -78,8 +79,8 @@ def get_args(raw_args):
     )
     parser.add_argument(
         '-p', '--patch',
-        dest='patch',
-        action='store_true',
+        dest='patches',
+        action='append',
         help='Open a shell before configuration to allow patching'
     )
     parser.add_argument(
@@ -96,7 +97,6 @@ def get_args(raw_args):
         default=None,
         help='directory for kernel configs'
     )
-
     return parser.parse_args(raw_args)
 
 
@@ -126,6 +126,14 @@ def get_current_kernel_revision():
         return '0'
 
 
+def run_patches(patches):
+    for patch in args.patches:
+        if os.path.isdir(patch):
+            run_patches(glob.glob('{0}/*'.format(patch)))
+        elif os.access(patch, os.X_OK):
+            kernel.patch(patch)
+
+
 def devnull():
     return open(os.devnull, 'w')
 
@@ -285,7 +293,6 @@ class Kernel(object):
         else:
             callback = None
         try:
-            self.log("Trying to open {0}".format(source))
             archive = TarFileWithProgress.open(source, callback=callback)
             archive.extractall(destination)
         except:
@@ -295,6 +302,12 @@ class Kernel(object):
             )
             raise
 
+    @require_attr('version')
+    def patch(self, patch_script):
+        os.chdir('{0}/sources/linux-{1}'.format(self.build_dir, self.version))
+        self.log('Applying patch: {0}'.format(patch_script))
+        subprocess.call([patch_script])
+
     @require_attr('version')
     @require_attr('revision')
     @require_attr('config_version')
@@ -474,9 +487,8 @@ def easy_roll(raw_args):
 
     kernel.download()
     kernel.extract()
-    if args.patch:
-        print('Dropping into a bash shell for patching; `exit` to continue')
-        os.system('bash')
+    if args.patches:
+        run_patches()
     kernel.configure()
     if modify:
         kernel.modify()
